# WordMarker

[![PyPI](https://img.shields.io/pypi/v/wordmarker)](https://pypi.org/project/wordmarker/) [![Read the Docs](https://img.shields.io/readthedocs/wordmarker)](https://wordmarker.readthedocs.io/) [![GitHub](https://img.shields.io/github/license/lostblackknight/wordmarker)](https://opensource.org/licenses/MIT)

Word文档生成器。

## 安装

WordMarker在[PyPI](https://pypi.org/project/wordmarker/)上发布，可以从那里安装：

```python
pip install wordmarker -i https://pypi.org/simple
```

国内用户建议直接[下载](https://pypi.org/project/wordmarker/#files)进行安装。

## 文档资料

- 你可以从[wordmarker.readthedocs.io](https://wordmarker.readthedocs.io/)获取文档。
- 你也可以从[wordmarker.rtfd.io](http://wordmarker.rtfd.io/)获取文档。

## 保持联系

- 你可以在[Github](https://github.com/lostblackknight/wordmarker)上，反馈漏洞，提出建议，查看源码。
- 其他问题，请使用E-mail : chensixiang1234@gmail.com。